      PROGRAM INDHEAT
C
C   This program simulates induction heating of a plate of normalised 
C   thickness (-1)-x-(1), per unit area. The temperature refered to the
C   initial temperature.
C   Induction heating is considered aproximately equal to a constant 
C   flux of heat in the surface of the material and the thermal and 
C   physical properties of the material are considered constant in the
C   range of temperatures used.
C
C
      INTEGER I, J, I2, IC, IMAX, JMAX
      PARAMETER (IMAX = 200 )
      PARAMETER (JMAX = 6 )
      DOUBLE PRECISION  X, KTH, T0, Q, TACT(0:(JMAX-1)), 
     *       EVALT, R, QRK, ECOOL, TH2O, H, 
     *       THI(0:(JMAX-1)),RO, CP, TMAX
      REAL TIC(0:(JMAX-1)), INCT, TIME
C
C     Some values are considered standard, K, T0, inct
C
      DATA INCT, T0, TH2O, TIME/0.1, 25.0, 25.0, 0.0/
C
C    These DATA statements have to be changed if JMAX not + 6
C
      DATA KTH, TACT, TMAX, R /41.0, 6*25.0, 1200.0, 0.005/
      DATA RO, CP, TIC / 7700.0, 600.0, 6*0.0/
C   H - Quenching severity, H = h/k
      DATA H  / 855.0 /
C
C     The program asks for properties of the material, and
C     for the heat flux input
C
C
C
      PRINT *,'Input the heat flux applied'
      READ *,Q
C
C     Iterations to calculate temp=f(x,t)
C
C
      QRK = Q / (R*KTH)

      PRINT 105 
C
C	The TIME iteration begins
C
      PRINT 101, 0, TIME, (TACT(I2), I2 = 0,(JMAX-1))
      DO 20 I =1, IMAX
         TIME=TIME + INCT
C
C      The SPACE iteration begins
C
         DO 30 J = 0, (JMAX-1)
            X =1.0* J*(1.0/(JMAX-1.0))  
            TACT(J)=EVALT(QRK, KTH, X, TIME)
C
  30     CONTINUE
C
C      Convert to real temperature to print results of this iteration
C         T = TACT + 25 oC
C
         DO 40 I2 = 0,(JMAX-1)
             TACT(I2) = TACT(I2) + T0
  40     CONTINUE
C
         PRINT 101, I, TIME, (TACT(I2), I2 = 0,(JMAX-1))
C
C     Breaks the loop if the surface temperature reaches Tmax
C
         IC = I + 1
         IF (TACT(JMAX-1).GT.TMAX) GOTO 60 

  20  CONTINUE
C
      STOP
C
  60  PRINT *,''
      PRINT *,''
      PRINT 103, TMAX
      PRINT *,''
      PRINT *,''
      DO 80 I2=0, (JMAX-1)
         THI(I2) = TACT(I2)
  80  CONTINUE
C
C     Now the component is cooled with water sprays
C        
C  ***      
      PRINT 105 
C
C	The TIME iteration begins again, for cooling 
C         
C
      PRINT 101, I, TIME, (TACT(I2), I2 = 0,(JMAX-1))
      DO 25 I = IC, (IMAX)
         TIME=TIME + INCT

C
C      The SPACE iteration begins
C
         DO 35 J = 0, (JMAX-1)
C 
            IF (J.LT.(JMAX-1)) THEN
                IF(THI(J).GT.TACT(J+1)) THEN
                   TIC(J) = TIC(J) + INCT
                ENDIF
            ELSE
                   TIC(J) = TIC(J) + INCT
            END IF
            X =1.0* J*(1.0/(JMAX-1.0))  
            TACT(J)= ECOOL(KTH, R, RO, CP, H, X, TIC(J),
     *              THI(J), TH2O)
C 
C
C  
  35     CONTINUE
C
C      This time the results are in real temperature 
C
         PRINT 101, I, TIME, (TACT(I2), I2 = 0,(JMAX-1))
C
C     Breaks the loop if the surface temperature reaches T0
C     Otherwise, recalculates heat flow and 'reloops' for time
C
         IF (TACT(JMAX-1).LT.T0) GOTO 65 
C
  25  CONTINUE
      PRINT *,''
      PRINT *,'Maximum number of iterations,', JMAX, ', already ran'
      PRINT *,''
      STOP
C

  65  PRINT *,''
      PRINT *,''
      PRINT 103, TH2O
      PRINT *,''
      PRINT *,''

C  ***
      STOP
C
C  
C
C     Formats for output
C
C     IMPORTANT: If JMAX is changed from 6, these FORMATs have to be changed
C
 101  FORMAT (4X, I3, 5X, F6.2, ' s',  4X, F6.1, 2X, F6.1, 2X,
     *         F6.1, 2X, F6.1, 2X, F6.1, 2X, F6.1)
 105  FORMAT ('ITERATION', 5X, 'TIME', 5X, 'T@0.0L', 2X, 'T@0.2L', 2X,
     *        'T@0.4L', 2X, 'T@0.6L', 2X, 'T@0.8L', 2X, 'T@1.0L', 5X,
     *         '(^oC)')
 103  FORMAT('The limit temperature',2X,F6.1,1X,'C has been achieved')
C
      END
C
C
C
C
C   **********************************************************
C   **********************************************************
C
C   FUNCTION Evaluate temperature (heat flux, time, position)
C
C
      DOUBLE PRECISION FUNCTION EVALT(B, K, X, TIME)
C
C
C
C
      INTEGER N, NMAX
      PARAMETER (NMAX = 100)
      DOUBLE PRECISION  B, K, X, TIME, Z1, Z2, ERFC1, ERFC2,
     *         VALN, ACUM, ERFC 
C
C
C
      DO 70 N = 0, NMAX
C
         Z1 = ((2.0*N - X +1.0)/SQRT(K))/2.0*SQRT(TIME)       
         Z2 = ((2.0*N + X +1.0)/SQRT(K))/2.0*SQRT(TIME)       
         ERFC1 = ERFC(Z1)
         ERFC2 = ERFC(Z2)
         VALN = ERFC1 - ERFC2
         ACUM = ACUM + VALN
  70  CONTINUE
C
      EVALT = B * ACUM
C
      RETURN
      END
C
C
C
C    ************************************************************
C    ************************************************************
C
C
C
C       Function to evaluate complementary error function 
C		Following W.H. Press et al.
C
C
      DOUBLE PRECISION FUNCTION ERFC(X)
C
C
      DOUBLE PRECISION X, Z, T
C
      Z = ABS(X)
      T = 1.0 / (1.0 + 0.5 * Z)
C
      ERFC = T*EXP(-Z*Z-1.26551223+T*(1.00002368+T*(.37409196+
     *      T*(.09678418+T*(-.18628806+T*(.27886807+T*(-1.13520398+
     *      T*(1.48851587+T*(-.82215223+T*.17087277)))))))))
C
      IF (X.LT.0.) ERFC = 2. -ERFC
      RETURN
      END
C
C
C
C   *****************************************************************
C   *****************************************************************
C
C       Function to evaluate cooling by water spray
C       (forced convective cooling) after Poirier &
C        Geiger (pp 302) and Carslaw & Jaeger
C
      DOUBLE PRECISION FUNCTION ECOOL(KTH, R, RO, CP, H, 
     *     X, TIME, TI, TF)
C
C
      DOUBLE PRECISION  ACUM, KTH, R, RO, CP, H, X, 
     *        BI, FO, A1, A2, A3, ERFC, TI, TF
      REAL TIME
C
      BI = H * R
      FO = (KTH * TIME) / (RO*CP*(R**2))
      A1 = ERFC((1.0-X)/(2.0*SQRT(FO))) + 
     *           ERFC((1.0+X)/(2.0*SQRT(FO)))
      A2 = EXP(BI*(1.0-X) + FO*BI**2)*ERFC(BI*SQRT(FO)+
     *           (1-X)/(2.0*SQRT(FO)))
      A3 = EXP(BI*(1.0+X) + FO*BI**2)*ERFC(BI*SQRT(FO)+
     *           (1+X)/(2.0*SQRT(FO)))

      ACUM = 1 - A1 + A2 + A3
C
C
      ECOOL = (TF + ACUM*(TI - TF))
C
      RETURN
      END



   
